@@ -2,12 +2,11 @@ package fluentd
 
 import (
 	"fmt"
+	logging "github.com/openshift/cluster-logging-operator/apis/logging/v1"
 	"github.com/openshift/cluster-logging-operator/internal/constants"
 	"github.com/openshift/cluster-logging-operator/internal/generator"
 	source2 "github.com/openshift/cluster-logging-operator/internal/generator/fluentd/source"
 	"strings"
-
-	logging "github.com/openshift/cluster-logging-operator/apis/logging/v1"
 )
 
 func Sources(clspec *logging.ClusterLoggingSpec, spec *logging.ClusterLogForwarderSpec, o generator.Options) []generator.Element {
@@ -98,28 +97,13 @@ func LogSources(spec *logging.ClusterLogForwarderSpec, tunings *logging.FluentdI
 }
 
 func ContainerLogPaths() string {
-	return fmt.Sprintf("%q", "/var/log/containers/*.log")
-}
-
-func CollectorLogsPath() string {
-	return fmt.Sprintf("/var/log/containers/%%s-*_%s_*.log", constants.OpenshiftNS)
-}
-
-func LogStoreLogsPath() string {
-	return fmt.Sprintf("/var/log/containers/%%s-*_%s_*.log", constants.OpenshiftNS)
-}
-
-func VisualizationLogsPath() string {
-	return fmt.Sprintf("/var/log/containers/%%s-*_%s_*.log", constants.OpenshiftNS)
+	return fmt.Sprintf("%q", "/var/log/pods/**/*.log")
 }
 
 func ExcludeContainerPaths() string {
-	return fmt.Sprintf("[%s]", strings.Join(
-		[]string{
-			fmt.Sprintf("%q", fmt.Sprintf(CollectorLogsPath(), constants.CollectorName)),
-			fmt.Sprintf("%q", fmt.Sprintf(LogStoreLogsPath(), constants.ElasticsearchName)),
-			fmt.Sprintf("%q", fmt.Sprintf(VisualizationLogsPath(), constants.KibanaName)),
-		},
-		", ",
-	))
+	paths := []string{}
+	for _, comp := range []string{constants.CollectorName, constants.ElasticsearchName, constants.KibanaName} {
+		paths = append(paths, fmt.Sprintf("\"/var/log/pods/%s_%s-*/*/*.log\"", constants.OpenshiftNS, comp))
+	}
+	return fmt.Sprintf("[%s]", strings.Join(paths, ", "))
 }
