@@ -3,13 +3,13 @@ package k8shandler
 import (
 	"context"
 	"fmt"
-	"io/ioutil"
-	"os"
 	"path"
 	"reflect"
 	"strings"
 	"time"
 
+	"github.com/openshift/cluster-logging-operator/internal/runtime"
+
 	"github.com/openshift/cluster-logging-operator/internal/components/fluentd"
 	"github.com/openshift/cluster-logging-operator/internal/constants"
 	"github.com/openshift/cluster-logging-operator/internal/factory"
@@ -74,11 +74,16 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection() (err err
 		if err = clusterRequest.removeCollector(constants.FluentdName); err != nil {
 			log.V(2).Info("Error removing legacy fluentd collector.  ", "err", err)
 		}
-		enabled, present := os.LookupEnv("ENABLE_VECTOR_COLLECTOR")
-		if collectorType == logging.LogCollectionTypeVector && (!present || strings.ToLower(enabled) != "true") {
-			err = errors.NewBadRequest("Vector as collector not enabled via env variable ENABLE_VECTOR_COLLECTOR")
-			log.V(9).Error(err, "Vector as collector not enabled via env variable ENABLE_VECTOR_COLLECTOR")
-			return err
+		enabled, found := clusterRequest.Cluster.Annotations[PreviewVectorCollector]
+		if collectorType == logging.LogCollectionTypeVector && (!found || enabled != "enabled") {
+			err = errors.NewBadRequest(fmt.Sprintf("Vector as collector not enabled via annotation on ClusterLogging %s", PreviewVectorCollector))
+			log.V(9).Error(err, "Vector as collector not enabled via annotation on ClusterLogging")
+			return clusterRequest.UpdateCondition(
+				logging.CollectorDeadEnd,
+				"Add annotation \"logging.openshift.io/preview-vector-collector: enabled\" to ClusterLogging CR",
+				"Vector as collector not enabled via annotation on ClusterLogging",
+				corev1.ConditionTrue,
+			)
 		}
 
 		if err = clusterRequest.createOrUpdateCollectionPriorityClass(); err != nil {
@@ -86,13 +91,13 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection() (err err
 			return
 		}
 
-		if collectorServiceAccount, err = clusterRequest.createOrUpdateCollectorServiceAccount(); err != nil {
-			log.V(9).Error(err, "clusterRequest.createOrUpdateCollectorServiceAccount")
+		if err = clusterRequest.removeCollectorSecretIfOwnedByCLO(); err != nil {
+			log.Error(err, "Can't fully clean up old secret created by CLO")
 			return
 		}
 
-		if err = clusterRequest.createOrUpdateCollectorSecret(); err != nil {
-			log.V(9).Error(err, "clusterRequest.createOrUpdateCollectorSecret")
+		if collectorServiceAccount, err = clusterRequest.createOrUpdateCollectorServiceAccount(); err != nil {
+			log.V(9).Error(err, "clusterRequest.createOrUpdateCollectorServiceAccount")
 			return
 		}
 
@@ -122,8 +127,8 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection() (err err
 			log.V(9).Error(err, "unable to create or update fluentd prometheus rule")
 		}
 
-		if err = clusterRequest.createOrUpdateCollectorConfigMap(collectorType, collectorConfig); err != nil {
-			log.V(9).Error(err, "clusterRequest.createOrUpdateCollectorConfigMap")
+		if err = clusterRequest.createOrUpdateCollectorConfig(collectorType, collectorConfig); err != nil {
+			log.V(9).Error(err, "clusterRequest.createOrUpdateCollectorConfig")
 			return
 		}
 
@@ -147,7 +152,7 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection() (err err
 			}
 		}
 	} else {
-		if err = clusterRequest.RemoveServiceAccount("logcollector"); err != nil {
+		if err = clusterRequest.RemoveServiceAccount(constants.CollectorServiceAccountName); err != nil {
 			return
 		}
 
@@ -163,6 +168,23 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection() (err err
 	return nil
 }
 
+// need for smooth upgrade CLO to the 5.4 version, after moving certificates generation to the EO side
+// see details: https://issues.redhat.com/browse/LOG-1923
+func (clusterRequest *ClusterLoggingRequest) removeCollectorSecretIfOwnedByCLO() (err error) {
+	secret, err := clusterRequest.GetSecret(constants.CollectorSecretName)
+	if err != nil && !errors.IsNotFound(err) {
+		return err
+	}
+	if utils.IsOwnedBy(secret.GetOwnerReferences(), utils.AsOwner(clusterRequest.Cluster)) {
+		err = clusterRequest.RemoveSecret(constants.CollectorSecretName)
+		if err != nil && !errors.IsNotFound(err) {
+			log.Error(err, fmt.Sprintf("Can't remove %s secret", constants.CollectorSecretName))
+			return err
+		}
+	}
+	return nil
+}
+
 func (clusterRequest *ClusterLoggingRequest) removeCollector(name string) (err error) {
 	if clusterRequest.isManaged() {
 
@@ -193,36 +215,6 @@ func (clusterRequest *ClusterLoggingRequest) removeCollector(name string) (err e
 
 		// Wait longer than the terminationGracePeriodSeconds
 		time.Sleep(12 * time.Second)
-
-		if err = clusterRequest.RemoveSecret(name); err != nil {
-			return
-		}
-
-	}
-
-	return nil
-}
-
-func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorSecret() error {
-	var secrets = map[string][]byte{}
-	_ = Syncronize(func() error {
-		secrets = map[string][]byte{}
-		// Ignore errors, these files are optional depending on security settings.
-		secrets["ca-bundle.crt"], _ = ioutil.ReadFile(utils.GetWorkingDirFilePath("ca.crt"))
-		secrets["tls.key"], _ = ioutil.ReadFile(utils.GetWorkingDirFilePath("system.logging.fluentd.key"))
-		secrets["tls.crt"], _ = ioutil.ReadFile(utils.GetWorkingDirFilePath("system.logging.fluentd.crt"))
-		return nil
-	})
-	collectorSecret := NewSecret(
-		constants.CollectorName,
-		clusterRequest.Cluster.Namespace,
-		secrets)
-
-	utils.AddOwnerRefToObject(collectorSecret, utils.AsOwner(clusterRequest.Cluster))
-
-	err := clusterRequest.CreateOrUpdateSecret(collectorSecret)
-	if err != nil {
-		return err
 	}
 
 	return nil
@@ -395,10 +387,11 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorPrometheusRu
 	})
 }
 
-func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorConfigMap(collectorType logging.LogCollectionType, collectorConfig string) error {
-	var collectorConfigMap *corev1.ConfigMap = nil
+func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorConfig(collectorType logging.LogCollectionType, collectorConfig string) error {
+	log.V(3).Info("Updating ConfigMap and Secrets")
+	var err error = nil
 	if collectorType == logging.LogCollectionTypeFluentd {
-		collectorConfigMap = NewConfigMap(
+		collectorConfigMap := NewConfigMap(
 			constants.CollectorName,
 			clusterRequest.Cluster.Namespace,
 			map[string]string{
@@ -406,16 +399,26 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorConfigMap(co
 				"run.sh":      fluentd.RunScript,
 			},
 		)
+		err = clusterRequest.createConfigMap(collectorConfigMap)
+
 	} else if collectorType == logging.LogCollectionTypeVector {
-		collectorConfigMap = NewConfigMap(
-			constants.CollectorName,
-			clusterRequest.Cluster.Namespace,
-			map[string]string{
-				"vector.toml": collectorConfig,
-			},
-		)
+		var secrets = map[string][]byte{}
+		_ = Syncronize(func() error {
+			secrets = map[string][]byte{}
+			// Ignore errors, these files are optional depending on security settings.
+			secrets["vector.toml"] = []byte(collectorConfig)
+			return nil
+		})
+		err = clusterRequest.createSecret(constants.CollectorConfigSecretName, clusterRequest.Cluster.Namespace, secrets)
+	}
+	if err != nil {
+		return err
 	}
 
+	return nil
+}
+
+func (clusterRequest *ClusterLoggingRequest) createConfigMap(collectorConfigMap *corev1.ConfigMap) error {
 	utils.AddOwnerRefToObject(collectorConfigMap, utils.AsOwner(clusterRequest.Cluster))
 
 	err := clusterRequest.Create(collectorConfigMap)
@@ -437,10 +440,16 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorConfigMap(co
 		current.Data = collectorConfigMap.Data
 		return clusterRequest.Update(current)
 	})
-
 	return retryErr
 }
 
+func (clusterRequest *ClusterLoggingRequest) createSecret(secretName, namespace string, secrets map[string][]byte) error {
+	collectorSecret := NewSecret(secretName, namespace, secrets)
+	utils.AddOwnerRefToObject(collectorSecret, utils.AsOwner(clusterRequest.Cluster))
+	err := clusterRequest.CreateOrUpdateSecret(collectorSecret)
+	return err
+}
+
 func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorDaemonset(collectorType logging.LogCollectionType, pipelineConfHash string) (err error) {
 	var fluentdTrustBundle *v1.ConfigMap
 	// Create or update cluster proxy trusted CA bundle.
@@ -479,7 +488,7 @@ func (clusterRequest *ClusterLoggingRequest) UpdateFluentdStatus() (err error) {
 		return nil
 	})
 	if retryErr != nil {
-		return fmt.Errorf("Failed to update Cluster Logging Collector status: %v", retryErr)
+		return fmt.Errorf("Failed to update Cluster Logging collector status: %v", retryErr)
 	}
 
 	return nil
@@ -526,7 +535,7 @@ func compareFluentdCollectorStatus(lhs, rhs logging.FluentdCollectorStatus) bool
 
 func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectionPriorityClass() error {
 
-	collectionPriorityClass := NewPriorityClass(clusterLoggingPriorityClassName, 1000000, false, "This priority class is for the Cluster-Logging Collector")
+	collectionPriorityClass := NewPriorityClass(clusterLoggingPriorityClassName, 1000000, false, "This priority class is for the Cluster-Logging collector")
 
 	utils.AddOwnerRefToObject(collectionPriorityClass, utils.AsOwner(clusterRequest.Cluster))
 
@@ -542,7 +551,7 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorServiceAccou
 
 	cluster := clusterRequest.Cluster
 
-	collectorServiceAccount := NewServiceAccount(constants.CollectorServiceAccountName, cluster.Namespace)
+	collectorServiceAccount := runtime.NewServiceAccount(clusterRequest.Cluster.Namespace, constants.CollectorServiceAccountName)
 
 	utils.AddOwnerRefToObject(collectorServiceAccount, utils.AsOwner(clusterRequest.Cluster))
 
@@ -554,7 +563,7 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorServiceAccou
 		}
 		err := clusterRequest.Create(collectorServiceAccount)
 		if err != nil && !errors.IsAlreadyExists(err) {
-			return nil, fmt.Errorf("Failure creating Log Collector service account: %v", err)
+			return nil, fmt.Errorf("Failure creating Log collector service account: %v", err)
 		}
 		if len(collectorServiceAccount.ObjectMeta.UID) != 0 {
 			serviceAccountLogCollectorUID = collectorServiceAccount.ObjectMeta.UID
@@ -569,7 +578,7 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorServiceAccou
 	scc := NewSCC(LogCollectorSCCName)
 	err := clusterRequest.Create(scc)
 	if err != nil && !errors.IsAlreadyExists(err) {
-		return nil, fmt.Errorf("Failure creating Log Collector SecurityContextConstraints: %v", err)
+		return nil, fmt.Errorf("Failure creating Log collector SecurityContextConstraints: %v", err)
 	}
 
 	// Also create the role and role binding so that the service account has host read access
@@ -595,7 +604,7 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorServiceAccou
 
 	subject := NewSubject(
 		"ServiceAccount",
-		"logcollector",
+		constants.CollectorServiceAccountName,
 	)
 	subject.APIGroup = ""
 
@@ -630,7 +639,7 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectorServiceAccou
 	}
 	subject = NewSubject(
 		"ServiceAccount",
-		"logcollector",
+		constants.CollectorServiceAccountName,
 	)
 	subject.Namespace = cluster.Namespace
 	subject.APIGroup = ""
