@@ -38,6 +38,8 @@ const (
 	logOauthapiserverValue = "/var/log/oauth-apiserver"
 	logOpenshiftapiserver  = "varlogopenshiftapiserver"
 
+	logJournalTransientValue = "/run/log/journal"
+
 	logOpenshiftapiserverValue = "/var/log/openshift-apiserver"
 	logKubeapiserver           = "varlogkubeapiserver"
 	logKubeapiserverValue      = "/var/log/kube-apiserver"
@@ -224,7 +226,7 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, trustedCABundleCM *v1.Co
 	)
 
 	fluentdPodSpec := NewPodSpec(
-		"logcollector",
+		constants.CollectorServiceAccountName,
 		[]v1.Container{fluentdContainer, exporterContainer},
 		[]v1.Volume{
 			{Name: logVolumeMountName, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: logVolumePath}}},
