@@ -3,7 +3,7 @@ package client
 import (
 	"fmt"
 
-	loggingv1 "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
+	loggingv1 "github.com/openshift/cluster-logging-operator/apis/logging/v1"
 	"github.com/openshift/cluster-logging-operator/test"
 	"k8s.io/apimachinery/pkg/watch"
 )
