@@ -2,6 +2,8 @@ package fluentd
 
 import (
 	"fmt"
+	"github.com/ViaQ/logerr/log"
+	"runtime"
 
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
@@ -32,6 +34,8 @@ func checkMountReadOnly(mount string) {
 }
 
 var _ = Describe("Tests of collector container security stance", func() {
+	_, filename, _, _ := runtime.Caller(0)
+	log.Info("Running ", "filename", filename)
 	e2e := framework.NewE2ETestFramework()
 
 	BeforeEach(func() {
