@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"github.com/ViaQ/logerr/log"
+	logging "github.com/openshift/cluster-logging-operator/apis/logging/v1"
 	"github.com/openshift/cluster-logging-operator/internal/utils"
 	"github.com/openshift/cluster-logging-operator/test"
 	"github.com/openshift/cluster-logging-operator/test/helpers/cmd"
@@ -12,7 +13,7 @@ import (
 	"strings"
 )
 
-func (f *FluentdFunctionalFramework) ReadApplicationLogsFrom(outputName string) ([]types.ApplicationLog, error) {
+func (f *CollectorFunctionalFramework) ReadApplicationLogsFrom(outputName string) ([]types.ApplicationLog, error) {
 	raw, err := f.ReadLogsFrom(outputName, applicationLog)
 	if err != nil {
 		return nil, err
@@ -25,14 +26,14 @@ func (f *FluentdFunctionalFramework) ReadApplicationLogsFrom(outputName string)
 	return logs, nil
 }
 
-func (f *FluentdFunctionalFramework) ReadRawApplicationLogsFrom(outputName string) ([]string, error) {
+func (f *CollectorFunctionalFramework) ReadRawApplicationLogsFrom(outputName string) ([]string, error) {
 	return f.ReadLogsFrom(outputName, applicationLog)
 }
 
-func (f *FluentdFunctionalFramework) ReadInfrastructureLogsFrom(outputName string) ([]string, error) {
+func (f *CollectorFunctionalFramework) ReadInfrastructureLogsFrom(outputName string) ([]string, error) {
 	return f.ReadLogsFrom(outputName, infraLog)
 }
-func (f *FluentdFunctionalFramework) ReadApplicationLogsFromKafka(topic string, brokerlistener string, consumercontainername string) (results []string, err error) {
+func (f *CollectorFunctionalFramework) ReadApplicationLogsFromKafka(topic string, brokerlistener string, consumercontainername string) (results []string, err error) {
 	//inter broker zookeeper connect is plaintext so use plaintext port to check on sent messages from kafka producer ie. fluent-kafka plugin
 	//till this step it must be ensured that a topic is created and published in kafka-consumer-clo-app-topic container within functional pod
 	var result string
@@ -53,49 +54,64 @@ func (f *FluentdFunctionalFramework) ReadApplicationLogsFromKafka(topic string,
 	return results, err
 }
 
-func (f *FluentdFunctionalFramework) ReadAuditLogsFrom(outputName string) ([]string, error) {
+func (f *CollectorFunctionalFramework) ReadAuditLogsFrom(outputName string) ([]string, error) {
 	return f.ReadLogsFrom(outputName, auditLog)
 }
 
-func (f *FluentdFunctionalFramework) Readk8sAuditLogsFrom(outputName string) ([]string, error) {
+func (f *CollectorFunctionalFramework) Readk8sAuditLogsFrom(outputName string) ([]string, error) {
 	return f.ReadLogsFrom(outputName, k8sAuditLog)
 }
 
-func (f *FluentdFunctionalFramework) ReadOvnAuditLogsFrom(outputName string) ([]string, error) {
+func (f *CollectorFunctionalFramework) ReadOvnAuditLogsFrom(outputName string) ([]string, error) {
 	return f.ReadLogsFrom(outputName, ovnAuditLog)
 }
 
-func (f *FluentdFunctionalFramework) ReadLogsFrom(outputName string, outputLogType string) (results []string, err error) {
+func (f *CollectorFunctionalFramework) ReadLogsFrom(outputName, sourceType string) (results []string, err error) {
 	outputSpecs := f.Forwarder.Spec.OutputMap()
-	outputLog := outputName
+	outputType := outputName
 	if output, found := outputSpecs[outputName]; found {
-		outputLog = output.Type
+		outputType = output.Type
 	}
-	var result string
-	outputType, ok := outputLogFile[outputLog]
-	if !ok {
-		return nil, fmt.Errorf(fmt.Sprintf("cant find output of type %s in outputSpec %v", outputName, outputSpecs))
-	}
-	file, ok := outputType[outputLogType]
-	if !ok {
-		return nil, fmt.Errorf(fmt.Sprintf("can't find log of type %s", outputLogType))
-	}
-	err = wait.PollImmediate(defaultRetryInterval, f.GetMaxReadDuration(), func() (done bool, err error) {
-		result, err = f.RunCommand(outputName, "cat", file)
-		if result != "" && err == nil {
-			return true, nil
+	readLogs := func() ([]string, error) {
+		var result string
+		outputFiles, ok := outputLogFile[outputType]
+		if !ok {
+			return nil, fmt.Errorf(fmt.Sprintf("cant find output of type %s in outputSpec %v", outputName, outputSpecs))
 		}
-		log.V(4).Error(err, "Polling logs")
-		return false, nil
-	})
-	if err == nil {
-		results = strings.Split(strings.TrimSpace(result), "\n")
+		file, ok := outputFiles[sourceType]
+		if !ok {
+			return nil, fmt.Errorf(fmt.Sprintf("can't find log of type %s", sourceType))
+		}
+		err = wait.PollImmediate(defaultRetryInterval, f.GetMaxReadDuration(), func() (done bool, err error) {
+			result, err = f.RunCommand(outputName, "cat", file)
+			if result != "" && err == nil {
+				return true, nil
+			}
+			log.V(4).Error(err, "Polling logs")
+			return false, nil
+		})
+		if err == nil {
+			results = strings.Split(strings.TrimSpace(result), "\n")
+		}
+		log.V(4).Info("Returning", "logs", result)
+		return results, err
 	}
-	log.V(4).Info("Returning", "logs", result)
-	return results, err
+	if outputType == logging.OutputTypeElasticsearch {
+		readLogs = func() ([]string, error) {
+			result, err := f.GetLogsFromElasticSearch(outputName, sourceType)
+			if err == nil {
+				result = result[1:]
+				result = result[:len(result)-1]
+				return strings.Split(result, ","), nil
+			}
+			return nil, err
+		}
+	}
+
+	return readLogs()
 }
 
-func (f *FluentdFunctionalFramework) ReadNApplicationLogsFrom(n uint64, outputName string) ([]string, error) {
+func (f *CollectorFunctionalFramework) ReadNApplicationLogsFrom(n uint64, outputName string) ([]string, error) {
 	lines := []string{}
 	ctx, cancel := context.WithTimeout(context.Background(), test.SuccessTimeout())
 	defer cancel()
