@@ -15,12 +15,12 @@ var _ = Describe("[Functional][Outputs][Syslog] RFC3164 tests", func() {
 	const payload = `{"index":1,"timestamp":1}`
 
 	var (
-		framework          *functional.FluentdFunctionalFramework
+		framework          *functional.CollectorFunctionalFramework
 		maxReadDuration, _ = time.ParseDuration("30s")
 	)
 
 	BeforeEach(func() {
-		framework = functional.NewFluentdFunctionalFramework()
+		framework = functional.NewCollectorFunctionalFramework()
 		framework.MaxReadDuration = &maxReadDuration
 	})
 
@@ -52,7 +52,7 @@ var _ = Describe("[Functional][Outputs][Syslog] RFC3164 tests", func() {
 	},
 
 		Entry("should use the value from the record and include the message", "$.message.tag_key", "rec_tag"),
-		Entry("should use the value from the complete tag and include the message", "tag", `kubernetes\.var\.log.containers\..*`),
+		Entry("should use the value from the complete tag and include the message", "tag", `kubernetes\.var\.log.pods\..*`),
 		Entry("should use values from parts of the tag and include the message", "${tag[0]}#${tag[-2]}", `kubernetes#.*`),
 	)
 	Describe("configured with values for facility,severity", func() {
